@@ -24,20 +24,21 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 References:
 
-Corless, R. M.; Gonnet, G. H.; Hare, D. E.; Jeffrey, D. J. & Knuth, D. E. "On the Lambert W function", Advances in Computational Mathematics,
-Springer, 1996, 5, 329-359
+Corless, R. M.; Gonnet, G. H.; Hare, D. E.; Jeffrey, D. J. & Knuth, D. E.
+ "On the Lambert W function", Advances in Computational Mathematics,
+ Springer, 1996, 5, 329-359
 
 Veberič, Darko. "Lambert W function for applications in physics."
-Computer Physics Communications 183(12), 2012, 2622-2628
+ Computer Physics Communications 183(12), 2012, 2622-2628
 
-Veberič used for Fritsch iteration step; access to original paper currently unavailable
-Need to retain Halley step for -7e-3 < x 7e-3 where the Fritsch may underflow and return NaN
+Veberič used for Fritsch iteration step; access to original paper currently
+unavailable. Need to retain Halley step for -7e-3 < x 7e-3 where the Fritsch may
+underflow and return NaN
 */
+
 // [[Rcpp::interfaces(r, cpp)]]
-// [[Rcpp::depends(RcppParallel)]]
 #include <Rcpp.h>
 #include <RcppParallel.h>
-
 #include <cmath>
 
 using namespace Rcpp;
@@ -55,18 +56,18 @@ const double M_1_E = 1.0 / M_E;
 
 double FritschIter(double x, double w_guess){
   double w = w_guess;
-  int MaxEval = 6;
+  int MaxEval = 4;
   bool CONVERGED = false;
   double k = 2.0 / 3.0;
   int i = 0;
   do {
     double z = log(x / w) - w;
     double w1 = w + 1.0;
-    double q = 2 * w1 * (w1 + k * z);
+    double q = 2.0 * w1 * (w1 + k * z);
     double qz = q - z;
     double e = z / w1 * qz / (qz - z);
     CONVERGED = fabs(e) <= EPS;
-    w *= (1 + e);
+    w *= (1.0 + e);
     ++i;
   } while (!CONVERGED && i < MaxEval);
   return(w);
@@ -74,7 +75,8 @@ double FritschIter(double x, double w_guess){
 
   /* Halley Iteration
   Given x, we want to find W such that Wexp(W) = x, so Wexp(W) - x = 0.
-  We can use Halley iteration to find this root; to do so it needs first and second derivative.
+  We can use Halley iteration to find this root; to do so it needs first and
+  second derivative.
   f(W)    = W * exp(W) - x
   f'(W)   = W * exp(W) + exp(W)       = exp(W) * (W + 1)
   f''(W)  = exp(W) + (W + 1) * exp(W) = exp(W) * (W + 2)
@@ -84,14 +86,14 @@ double FritschIter(double x, double w_guess){
 
 double HalleyIter(double x, double w_guess){
   double w = w_guess;
-  int MaxEval = 12;
+  int MaxEval = 7;
   bool CONVERGED = false;
   int i = 0;
   do {
     double ew = exp(w);
     double w1 = w + 1.0;
     double f0 = w * ew - x;
-    f0 /= ((ew * w1) - (((w1 + 1.0) * f0) / (2 * w1))); /* Corliss et al. 5.9 */
+    f0 /= ((ew * w1) - (((w1 + 1.0) * f0) / (2.0 * w1))); // Corliss et al. 5.9
     CONVERGED = fabs(f0) <= EPS;
     w -= f0;
     ++i;
@@ -102,21 +104,22 @@ double HalleyIter(double x, double w_guess){
 double lambertW0_CS(double x) {
   double result;
   double w;
-  if (x == std::numeric_limits<double>::infinity()) {
-    result = std::numeric_limits<double>::infinity();
+  if (x == R_PosInf) {
+    result = R_PosInf;
   } else if (x < -M_1_E) {
-    result = std::numeric_limits<double>::quiet_NaN();
-  } else if (fabs(x + M_1_E) < 4 * EPS) {
+    result = R_NaN;
+  } else if (fabs(x + M_1_E) < 4.0 * EPS) {
     result = -1.0;
   } else if (x <= M_E - 0.5) {
       /* Use expansion in Corliss 4.22 to create (3, 2) Pade approximant
-      Numerator: -10189 / 303840 * p ^ 3 + 40529 / 303840 * p ^ 2 + 489 / 844 * p - 1
+      Numerator: -10189 / 303840 * p^3 + 40529 / 303840 * p^2 + 489 / 844 * p-1
       Denominator: -14009 / 303840 * p^2 + 355 / 844 * p + 1
       Converted to digits to reduce needed operations
       */
-    double p = sqrt(2 * (M_E * x + 1));
-    double Numer = ((-0.03353409689310163 * p + 0.1333892838335966) * p + 0.5793838862559242) * p - 1;
-    double Denom = (-0.04610650342285413 * p + 0.4206161137440758) * p + 1;
+    double p = sqrt(2.0 * (M_E * x + 1.0));
+    double Numer = ((-0.03353409689310163 * p + 0.1333892838335966) * p +
+                    0.5793838862559242) * p - 1.0;
+    double Denom = (-0.04610650342285413 * p + 0.4206161137440758) * p + 1.0;
     w = Numer / Denom;
     if (fabs(x) <= 7e-3) {
       /* Use Halley step near 0 as this version of Fritsch may underflow */
@@ -130,7 +133,8 @@ double lambertW0_CS(double x) {
     double L_2 = log(w);
     double L_3 = L_2 / w;
     double L_3_sq = L_3 * L_3;
-    w += -L_2 + L_3 + 0.5 * L_3_sq - L_3 / w + L_3 / (w * w) - 1.5 * L_3_sq / w + L_3_sq * L_3 / 3;
+    w += -L_2 + L_3 + 0.5 * L_3_sq - L_3 / w + L_3 / (w * w) - 1.5 * L_3_sq /
+      w + L_3_sq * L_3 / 3.0;
     result = FritschIter(x, w);
   }
   return(result);
@@ -139,11 +143,11 @@ double lambertW0_CS(double x) {
 double lambertWm1_CS(double x){
   double result;
   double w;
-  if (x == 0) {
-    result = -std::numeric_limits<double>::infinity();
+  if (x == 0.0) {
+    result = R_NegInf;
   } else if (x < -M_1_E || x > 0.0) {
-    result = std::numeric_limits<double>::quiet_NaN();
-  } else if (fabs(x + M_1_E) < 4 * EPS) {
+    result = R_NaN;
+  } else if (fabs(x + M_1_E) < 4.0 * EPS) {
     result = -1.0;
   } else {
     /* Use first five terms of Corliss et al. 4.19 */
@@ -151,7 +155,8 @@ double lambertWm1_CS(double x){
     double L_2 = log(-w);
     double L_3 = L_2 / w;
     double L_3_sq = L_3 * L_3;
-    w += -L_2 + L_3 + 0.5 * L_3_sq - L_3 / w + L_3 / (w * w) - 1.5 * L_3_sq / w + L_3_sq * L_3 / 3;
+    w += -L_2 + L_3 + 0.5 * L_3_sq - L_3 / w + L_3 / (w * w) - 1.5 * L_3_sq /
+      w + L_3_sq * L_3 / 3.0;
     result = FritschIter(x, w);
   }
   return(result);
